var fstarpu__mod_8f90 =
[
    [ "fstarpu_mod::operator(.ior.)", "namespacefstarpu__mod.html#interfacefstarpu__mod_1_1operator_07_8ior_8_08", null ],
    [ "fstarpu_mod::fstarpu_conf_init", "interfacefstarpu__mod_1_1fstarpu__conf__init.html", null ],
    [ "fstarpu_mod::fstarpu_conf_allocate", "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html", null ],
    [ "fstarpu_mod::fstarpu_conf_free", "interfacefstarpu__mod_1_1fstarpu__conf__free.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_sched_policy_name", "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_min_prio", "interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_max_prio", "interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_ncpu", "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_ncuda", "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html", null ],
    [ "fstarpu_mod::fstarpu_conf_set_nopencl", "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html", null ],
    [ "fstarpu_mod::fstarpu_pause", "interfacefstarpu__mod_1_1fstarpu__pause.html", null ],
    [ "fstarpu_mod::fstarpu_resume", "interfacefstarpu__mod_1_1fstarpu__resume.html", null ],
    [ "fstarpu_mod::fstarpu_is_paused", "interfacefstarpu__mod_1_1fstarpu__is__paused.html", null ],
    [ "fstarpu_mod::fstarpu_shutdown", "interfacefstarpu__mod_1_1fstarpu__shutdown.html", null ],
    [ "fstarpu_mod::fstarpu_topology_print", "interfacefstarpu__mod_1_1fstarpu__topology__print.html", null ],
    [ "fstarpu_mod::fstarpu_asynchronous_copy_disabled", "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html", null ],
    [ "fstarpu_mod::fstarpu_asynchronous_cuda_copy_disabled", "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html", null ],
    [ "fstarpu_mod::fstarpu_asynchronous_opencl_copy_disabled", "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html", null ],
    [ "fstarpu_mod::fstarpu_display_stats", "interfacefstarpu__mod_1_1fstarpu__display__stats.html", null ],
    [ "fstarpu_mod::fstarpu_get_version", "interfacefstarpu__mod_1_1fstarpu__get__version.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_count", "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_combined_worker_get_count", "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_worker_is_combined_worker", "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html", null ],
    [ "fstarpu_mod::fstarpu_cpu_worker_get_count", "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_cuda_worker_get_count", "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_opencl_worker_get_count", "interfacefstarpu__mod_1_1fstarpu__opencl__worker__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_id", "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_bindid", "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html", null ],
    [ "fstarpu_mod::fstarpu_combined_worker_get_id", "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html", null ],
    [ "fstarpu_mod::fstarpu_combined_worker_get_size", "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html", null ],
    [ "fstarpu_mod::fstarpu_combined_worker_get_rank", "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_type", "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_count_by_type", "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_ids_by_type", "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_by_type", "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_by_devid", "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_name", "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_devid", "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html", null ],
    [ "fstarpu_mod::fstarpu_worker_is_blocked", "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html", null ],
    [ "fstarpu_mod::fstarpu_worker_is_slave_somewhere", "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_type_as_string", "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html", null ],
    [ "fstarpu_mod::fstarpu_task_create_sync", "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html", null ],
    [ "fstarpu_mod::fstarpu_tag_declare_deps_array", "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html", null ],
    [ "fstarpu_mod::fstarpu_task_declare_deps", "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html", null ],
    [ "fstarpu_mod::fstarpu_task_declare_deps_array", "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html", null ],
    [ "fstarpu_mod::fstarpu_task_end_dep_add", "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html", null ],
    [ "fstarpu_mod::fstarpu_task_end_dep_release", "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html", null ],
    [ "fstarpu_mod::fstarpu_tag_wait", "interfacefstarpu__mod_1_1fstarpu__tag__wait.html", null ],
    [ "fstarpu_mod::fstarpu_tag_wait_array", "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html", null ],
    [ "fstarpu_mod::fstarpu_tag_notify_from_apps", "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html", null ],
    [ "fstarpu_mod::fstarpu_tag_restart", "interfacefstarpu__mod_1_1fstarpu__tag__restart.html", null ],
    [ "fstarpu_mod::fstarpu_tag_remove", "interfacefstarpu__mod_1_1fstarpu__tag__remove.html", null ],
    [ "fstarpu_mod::fstarpu_tag_get_task", "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html", null ],
    [ "fstarpu_mod::fstarpu_task_init", "interfacefstarpu__mod_1_1fstarpu__task__init.html", null ],
    [ "fstarpu_mod::fstarpu_task_clean", "interfacefstarpu__mod_1_1fstarpu__task__clean.html", null ],
    [ "fstarpu_mod::fstarpu_task_create", "interfacefstarpu__mod_1_1fstarpu__task__create.html", null ],
    [ "fstarpu_mod::fstarpu_task_destroy", "interfacefstarpu__mod_1_1fstarpu__task__destroy.html", null ],
    [ "fstarpu_mod::fstarpu_task_set_destroy", "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html", null ],
    [ "fstarpu_mod::fstarpu_task_submit", "interfacefstarpu__mod_1_1fstarpu__task__submit.html", null ],
    [ "fstarpu_mod::fstarpu_task_submit_to_ctx", "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html", null ],
    [ "fstarpu_mod::fstarpu_task_finished", "interfacefstarpu__mod_1_1fstarpu__task__finished.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait", "interfacefstarpu__mod_1_1fstarpu__task__wait.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_array", "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_for_all", "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_for_n_submitted", "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_for_all_in_ctx", "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_for_n_submitted_in_ctx", "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html", null ],
    [ "fstarpu_mod::fstarpu_task_wait_for_no_ready", "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html", null ],
    [ "fstarpu_mod::fstarpu_task_nready", "interfacefstarpu__mod_1_1fstarpu__task__nready.html", null ],
    [ "fstarpu_mod::fstarpu_task_nsubmitted", "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html", null ],
    [ "fstarpu_mod::fstarpu_do_schedule", "interfacefstarpu__mod_1_1fstarpu__do__schedule.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_init", "interfacefstarpu__mod_1_1fstarpu__codelet__init.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_display_stats", "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html", null ],
    [ "fstarpu_mod::fstarpu_task_get_current", "interfacefstarpu__mod_1_1fstarpu__task__get__current.html", null ],
    [ "fstarpu_mod::fstarpu_parallel_task_barrier_init_init", "interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html", null ],
    [ "fstarpu_mod::fstarpu_parallel_task_barrier_init_n_init_n", "interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html", null ],
    [ "fstarpu_mod::fstarpu_task_dup", "interfacefstarpu__mod_1_1fstarpu__task__dup.html", null ],
    [ "fstarpu_mod::fstarpu_task_set_implementation", "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html", null ],
    [ "fstarpu_mod::fstarpu_task_get_implementation", "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_allocate", "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_free", "interfacefstarpu__mod_1_1fstarpu__codelet__free.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_name", "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_color", "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_model", "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_energy_model", "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_cpu_func", "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_cuda_func", "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_cuda_flags", "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_opencl_func", "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_opencl_flags", "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_add_buffer", "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_variable_nbuffers", "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_nbuffers", "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_flags", "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_where", "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_type", "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html", null ],
    [ "fstarpu_mod::fstarpu_codelet_set_max_parallelism", "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html", null ],
    [ "fstarpu_mod::fstarpu_perfmodel_allocate", "interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html", null ],
    [ "fstarpu_mod::fstarpu_perfmodel_free", "interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html", null ],
    [ "fstarpu_mod::fstarpu_perfmodel_set_symbol", "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html", null ],
    [ "fstarpu_mod::fstarpu_perfmodel_set_type", "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html", null ],
    [ "fstarpu_mod::fstarpu_malloc_on_node", "interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_free_on_node", "interfacefstarpu__mod_1_1fstarpu__free__on__node.html", null ],
    [ "fstarpu_mod::fstarpug_data_ptr_register", "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_data_register_same", "interfacefstarpu__mod_1_1fstarpu__data__register__same.html", null ],
    [ "fstarpu_mod::fstarpu_data_handle_to_pointer", "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html", null ],
    [ "fstarpu_mod::fstarpu_data_get_local_ptr", "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_data_register", "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_ptr_register", "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_ptr", "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_ldy", "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_ldz", "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_ldt", "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_nx", "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_ny", "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_nz", "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html", null ],
    [ "fstarpu_mod::fstarpu_tensor_get_nt", "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html", null ],
    [ "fstarpu_mod::fstarpu_block_data_register", "interfacefstarpu__mod_1_1fstarpu__block__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_block_ptr_register", "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_ptr", "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_ldy", "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_ldz", "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_nx", "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_ny", "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html", null ],
    [ "fstarpu_mod::fstarpu_block_get_nz", "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_data_register", "interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_ptr_register", "interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_get_ptr", "interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_get_ld", "interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_get_nx", "interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_get_ny", "interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html", null ],
    [ "fstarpu_mod::fstarpu_vector_data_register", "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_vector_ptr_register", "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_vector_get_ptr", "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_vector_get_nx", "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html", null ],
    [ "fstarpu_mod::fstarpu_variable_data_register", "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_variable_ptr_register", "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html", null ],
    [ "fstarpu_mod::fstarpu_variable_get_ptr", "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_void_data_register", "interfacefstarpu__mod_1_1fstarpu__void__data__register.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_allocate", "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_free", "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_bcsr_filter_canonical_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_csr_filter_vertical_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_matrix_filter_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_matrix_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_matrix_filter_vertical_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_matrix_filter_vertical_block_shadow", "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_vector_filter_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_vector_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_vector_filter_list", "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_vector_filter_divide_in_2", "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_block_filter_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_block_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_block_filter_vertical_block", "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html", null ],
    [ "fstarpu_mod::fstarpu_df_alloc_block_filter_vertical_block_shadow", "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_filter_func", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_nchildren", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_get_nchildren_func", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_get_child_ops_func", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_filter_arg", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html", null ],
    [ "fstarpu_mod::fstarpu_data_filter_set_filter_arg_ptr", "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition", "interfacefstarpu__mod_1_1fstarpu__data__partition.html", null ],
    [ "fstarpu_mod::fstarpu_data_unpartition", "interfacefstarpu__mod_1_1fstarpu__data__unpartition.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition_plan", "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition_submit", "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition_readonly_submit", "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition_readwrite_upgrade_submit", "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_unpartition_submit", "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_unpartition_readonly_submit", "interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_partition_clean", "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html", null ],
    [ "fstarpu_mod::fstarpu_data_get_nb_children", "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html", null ],
    [ "fstarpu_mod::fstarpu_data_get_child", "interfacefstarpu__mod_1_1fstarpu__data__get__child.html", null ],
    [ "fstarpu_mod::fstarpu_data_get_sub_data", "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html", null ],
    [ "fstarpu_mod::fstarpu_data_map_filters", "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_filter_block", "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_filter_vertical_block", "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html", null ],
    [ "fstarpu_mod::fstarpu_matrix_filter_vertical_block_shadow", "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_vector_filter_block", "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_vector_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_vector_filter_list_long", "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html", null ],
    [ "fstarpu_mod::fstarpu_vector_filter_list", "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html", null ],
    [ "fstarpu_mod::fstarpu_vector_divide_in_2", "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_block", "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_block_shadow", "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_vertical_block", "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_vertical_block_shadow", "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_depth_block", "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html", null ],
    [ "fstarpu_mod::fstarpu_block_filter_depth_block_shadow", "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html", null ],
    [ "fstarpu_mod::fstarpu_data_unregister", "interfacefstarpu__mod_1_1fstarpu__data__unregister.html", null ],
    [ "fstarpu_mod::fstarpu_data_unregister_no_coherency", "interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html", null ],
    [ "fstarpu_mod::fstarpu_data_unregister_submit", "interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_deinitialize", "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html", null ],
    [ "fstarpu_mod::fstarpu_data_deinitialize_submit", "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_invalidate", "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html", null ],
    [ "fstarpu_mod::fstarpu_data_invalidate_submit", "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html", null ],
    [ "fstarpu_mod::fstarpu_data_advise_as_important", "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html", null ],
    [ "fstarpu_mod::fstarpu_data_acquire", "interfacefstarpu__mod_1_1fstarpu__data__acquire.html", null ],
    [ "fstarpu_mod::fstarpu_data_release", "interfacefstarpu__mod_1_1fstarpu__data__release.html", null ],
    [ "fstarpu_mod::fstarpu_data_release_on_node", "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_arbiter_create", "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html", null ],
    [ "fstarpu_mod::fstarpu_data_assign_arbiter", "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html", null ],
    [ "fstarpu_mod::fstarpu_arbiter_destroy", "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html", null ],
    [ "fstarpu_mod::fstarpu_display_memory_stats", "interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html", null ],
    [ "fstarpu_mod::fstarpu_data_request_allocation", "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html", null ],
    [ "fstarpu_mod::fstarpu_data_fetch_on_node", "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_data_prefetch_on_node", "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_data_prefetch_on_node_prio", "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html", null ],
    [ "fstarpu_mod::fstarpu_data_idle_prefetch_on_node", "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_data_idle_prefetch_on_node_prio", "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html", null ],
    [ "fstarpu_mod::fstarpu_data_is_on_node", "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_data_wont_use", "interfacefstarpu__mod_1_1fstarpu__data__wont__use.html", null ],
    [ "fstarpu_mod::fstarpu_worker_get_memory_node", "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html", null ],
    [ "fstarpu_mod::fstarpu_memory_nodes_get_count", "interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html", null ],
    [ "fstarpu_mod::fstarpu_data_set_reduction_methods", "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html", null ],
    [ "fstarpu_mod::fstarpu_data_set_reduction_methods_with_args", "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html", null ],
    [ "fstarpu_mod::fstarpu_data_test_if_allocated_on_node", "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html", null ],
    [ "fstarpu_mod::fstarpu_memchunk_tidy", "interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html", null ],
    [ "fstarpu_mod::fstarpu_data_handle_array_alloc", "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html", null ],
    [ "fstarpu_mod::fstarpu_data_handle_array_free", "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html", null ],
    [ "fstarpu_mod::fstarpu_data_handle_array_set", "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html", null ],
    [ "fstarpu_mod::fstarpu_data_descr_array_alloc", "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html", null ],
    [ "fstarpu_mod::fstarpu_data_descr_alloc", "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html", null ],
    [ "fstarpu_mod::fstarpu_data_descr_array_free", "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html", null ],
    [ "fstarpu_mod::fstarpu_data_descrg_free", "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html", null ],
    [ "fstarpu_mod::fstarpu_data_descr_array_set", "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html", null ],
    [ "fstarpu_mod::fstarpu_data_descr_set", "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html", null ],
    [ "fstarpu_mod::fstarpu_task_insert", "interfacefstarpu__mod_1_1fstarpu__task__insert.html", null ],
    [ "fstarpu_mod::fstarpu_insert_task", "interfacefstarpu__mod_1_1fstarpu__insert__task.html", null ],
    [ "fstarpu_mod::fstarpu_unpack_arg", "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html", null ],
    [ "fstarpu_mod::fstarpu_create_sync_task", "interfacefstarpu__mod_1_1fstarpu__create__sync__task.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_create", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_create_inside_interval", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_register_close_callback", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_add_workers", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_remove_workers", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_display_workers", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_delete", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_set_inheritor", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_inheritor", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_hierarchy_level", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_set_context", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_context", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_stop_task_submission", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_finished_submit", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_nworkers", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_nshared_workers", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_contains_worker", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_contains_type_of_worker", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_worker_get_id", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_ctx_for_task", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_overlapping_ctxs_on_worker", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html", null ],
    [ "fstarpu_mod::fstarpu_sched_get_min_priority", "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_get_max_priority", "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_set_min_priority", "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_set_max_priority", "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_min_priority", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_max_priority", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_set_min_priority", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_set_max_priority", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_min_priority_is_set", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_max_priority_is_set", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_user_data", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_delete_worker_collection", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_set_policy_data", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_policy_data", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_exec_parallel_code", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_nready_tasks", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_nready_flops", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_increment", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_decrement", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_reset", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_increment_all", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_decrement_all", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_list_task_counters_reset_all", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_priority", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_bind_current_thread_to_cpuid", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_book_workers_for_task", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_unbook_workers_for_task", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_worker_is_master_for_child_ctx", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_master_get_context", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_revert_task_counters", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_move_task_to_ctx", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_get_worker_rank", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html", null ],
    [ "fstarpu_mod::fstarpu_sched_ctx_call_pushed_task_cb", "interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_options_init", "interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_generate_trace", "interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_autostart_profiling", "interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_start_profiling", "interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_stop_profiling", "interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html", null ],
    [ "fstarpu_mod::fstarpu_fxt_write_data_trace", "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html", null ],
    [ "fstarpu_mod::fstarpu_trace_user_event", "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html", null ],
    [ "fstarpu_mod::fstarpu_timing_now", "interfacefstarpu__mod_1_1fstarpu__timing__now.html", null ],
    [ "fstarpu_mod::fstarpu_cuda_get_local_stream", "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html", null ],
    [ "fstarpu_mod::fstarpu_malloc", "interfacefstarpu__mod_1_1fstarpu__malloc.html", null ],
    [ "fstarpu_mod::fstarpu_free_noflag", "interfacefstarpu__mod_1_1fstarpu__free__noflag.html", null ],
    [ "fstarpu_mod::fstarpu_memory_pin", "interfacefstarpu__mod_1_1fstarpu__memory__pin.html", null ],
    [ "fstarpu_mod::fstarpu_memory_unpin", "interfacefstarpu__mod_1_1fstarpu__memory__unpin.html", null ],
    [ "fstarpu_mod::fstarpu_sleep", "interfacefstarpu__mod_1_1fstarpu__sleep.html", null ],
    [ "fstarpu_mod::fstarpu_usleep", "interfacefstarpu__mod_1_1fstarpu__usleep.html", null ],
    [ "fstarpu_mod::fstarpu_cublas_init", "interfacefstarpu__mod_1_1fstarpu__cublas__init.html", null ],
    [ "fstarpu_mod::fstarpu_cublas_shutdown", "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html", null ]
];